@@ -44,6 +44,11 @@
 #  include <wchar.h>
 #endif
 
+#ifdef G_OS_WIN32
+#if GLIB_CHECK_VERSION (2, 13, 2)
+#define pipe(phandles)  _pipe (phandles, 4096, _O_BINARY)
+#endif
+#endif
 /* Wrappers for C library function that take pathname arguments. */
 #if GLIB_CHECK_VERSION(2, 6, 0)
 #  include <glib/gstdio.h>
@@ -531,7 +536,7 @@ const gchar * line_has_quote_char	(const gchar *str,
 
 gint g_int_compare	(gconstpointer a, gconstpointer b);
 
-gchar *generate_msgid		(gchar *buf, gint len);
+gchar *generate_msgid		(gchar *buf, gint len, gchar *user_addr);
 gchar *generate_mime_boundary	(const gchar *prefix);
 
 gint quote_cmd_argument(gchar * result, guint size,
