@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -82,6 +82,8 @@ typedef struct {
 	Compose *compose;
 	GtkWidget *combo;
 	GtkWidget *entry;
+	GtkWidget *button;
+	GtkWidget *hbox;
 } ComposeHeaderEntry;
 
 struct _Compose
@@ -110,7 +112,7 @@ struct _Compose
 
 	/* Others */
 	GtkWidget *savemsg_checkbtn;
-	GtkWidget *savemsg_entry;
+	GtkWidget *savemsg_combo;
 
 	/* Headers notebook */
 	GtkWidget *notebook;
@@ -200,12 +202,6 @@ struct _Compose
 	GIOChannel *exteditor_ch;
 	gint        exteditor_tag;
 
-#if USE_ENCHANT
-        /* GNU/aspell spell checker */
-        GtkAspell *gtkaspell;
-	GtkWidget *aspell_options_menu;
-#endif
-
  	/* Priority */
  	gint priority;
 
@@ -235,6 +231,11 @@ struct _Compose
 	GtkWidget *first_entry;
 	
 	GtkUIManager *ui_manager;
+#if USE_ENCHANT
+        /* GNU/aspell spell checker */
+        GtkAspell *gtkaspell;
+	GtkWidget *aspell_options_menu;
+#endif
 };
 
 struct _AttachInfo
