@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2007 Match Grun and the Claws Mail team
+ * Copyright (C) 2001-2009 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -92,7 +92,7 @@ static gboolean editldap_validate_criteria( gchar *criteria ) {
 	gint i;
 	gboolean errorFlag;
 
-	g_return_val_if_fail(criteria != NULL, TRUE);
+	cm_return_val_if_fail(criteria != NULL, TRUE);
 
 	errorFlag = TRUE;
 
