@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,9 +62,9 @@ struct _FolderItemSearch
 	GtkTreeIter iter;
 };
 
-static GdkPixbuf *folder_pixbuf;
-static GdkPixbuf *folderopen_pixbuf;
-static GdkPixbuf *foldernoselect_pixbuf;
+static GdkPixbuf *folder_pixbuf = NULL;
+static GdkPixbuf *folderopen_pixbuf = NULL;
+static GdkPixbuf *foldernoselect_pixbuf = NULL;
 
 static GtkWidget *window;
 static GtkWidget *treeview;
@@ -201,7 +201,7 @@ FolderItem *foldersel_folder_sel(Folder *cur_folder, FolderSelectionType type,
 static void foldersel_size_allocate_cb(GtkWidget *widget,
 					 GtkAllocation *allocation)
 {
-	g_return_if_fail(allocation != NULL);
+	cm_return_if_fail(allocation != NULL);
 
 	prefs_common.folderselwin_width = allocation->width;
 	prefs_common.folderselwin_height = allocation->height;
@@ -345,6 +345,17 @@ static void foldersel_init(void)
 			 &foldernoselect_pixbuf);
 }
 
+void foldersel_reflect_prefs_pixmap_theme(void)
+{
+	if (folder_pixbuf)
+		g_object_unref(folder_pixbuf);
+	if (folderopen_pixbuf)
+		g_object_unref(folderopen_pixbuf);
+	if (foldernoselect_pixbuf)
+		g_object_unref(foldernoselect_pixbuf);
+	foldersel_init();
+}
+
 static void foldersel_append_item(GtkTreeStore *store, FolderItem *item,
 				  GtkTreeIter *iter, GtkTreeIter *parent)
 {
@@ -438,9 +449,9 @@ static void foldersel_insert_gnode_in_store(GtkTreeStore *store, GNode *node,
 	GtkTreeIter child;
 	GNode *iter;
 
-	g_return_if_fail(node != NULL);
-	g_return_if_fail(node->data != NULL);
-	g_return_if_fail(store != NULL);
+	cm_return_if_fail(node != NULL);
+	cm_return_if_fail(node->data != NULL);
+	cm_return_if_fail(store != NULL);
 
 	item = FOLDER_ITEM(node->data);
 	foldersel_append_item(store, item, &child, parent);
@@ -457,7 +468,7 @@ static void foldersel_set_tree(Folder *cur_folder, FolderSelectionType type)
 
 	for (list = folder_get_list(); list != NULL; list = list->next) {
 		folder = FOLDER(list->data);
-		g_return_if_fail(folder != NULL);
+		cm_return_if_fail(folder != NULL);
 
 		if (type != FOLDER_SEL_ALL) {
 			if (FOLDER_TYPE(folder) == F_NEWS)
