@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail Team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -337,7 +337,7 @@ static void prefswindow_build_tree(GtkWidget *tree_view, GSList *prefs_pages,
 			gtk_tree_model_foreach(GTK_TREE_MODEL(store), 
 					       (GtkTreeModelForeachFunc) find_node_by_name,
 					       &find_name);
-			if (find_name.found) {
+			if (find_name.found && page->path[i] != page->path[i-1]) {
 				node = find_name.node;
 				gtk_tree_model_get(GTK_TREE_MODEL(store), &node,
 						   PREFS_PAGE_DATA, &prefs_node,
@@ -619,7 +619,7 @@ static void prefs_size_allocate_cb(GtkWidget *widget,
 {
 	PrefsWindow *prefswindow = (PrefsWindow *) user_data;
 
-	g_return_if_fail(allocation != NULL);
+	cm_return_if_fail(allocation != NULL);
 
 	/* don't try to save size to NULL pointers */
 	if (prefswindow && prefswindow->save_width && prefswindow->save_height) {
