@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1971,7 +1971,7 @@ static void initial_processing(FolderItem *item, gpointer data)
 	MainWindow *mainwin = (MainWindow *)data;
 	gchar *buf;
 
-	g_return_if_fail(item);
+	cm_return_if_fail(item);
 	buf = g_strdup_printf(_("Processing (%s)..."), 
 			      item->path 
 			      ? item->path 
@@ -2341,10 +2341,9 @@ static void lock_socket_input_cb(gpointer data,
 		mailto = g_strdup(buf + strlen("compose_attach") + 1);
 		files = g_ptr_array_new();
 		while (fd_gets(sock, buf, sizeof(buf)) > 0) {
-			if (buf[0] == '.' && buf[1] == '\n') {
-				break;
-			}
 			strretchomp(buf);
+			if (!strcmp2(buf, "."))
+				break;
 			g_ptr_array_add(files, g_strdup(buf));
 		}
 		open_compose_new(mailto, files);
@@ -2494,7 +2493,7 @@ static void install_memory_sighandler()
 	struct sigaction act;
 	int flags;
 
-	mem_notify_fd = open("/dev/mem_notify", O_RDONLY|O_NONBLOCK);
+	mem_notify_fd = g_open("/dev/mem_notify", O_RDONLY|O_NONBLOCK, 0);
 	if (mem_notify_fd == -1) {
 		debug_print("/dev/mem_notify not available (%s)\n", 
 			strerror(errno));
