@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -92,8 +92,8 @@ gint proc_mbox(FolderItem *dest, const gchar *mbox, gboolean apply_filter,
 	gboolean printed = FALSE;
 	FolderItem *dropfolder;
 
-	g_return_val_if_fail(dest != NULL, -1);
-	g_return_val_if_fail(mbox != NULL, -1);
+	cm_return_val_if_fail(dest != NULL, -1);
+	cm_return_val_if_fail(mbox != NULL, -1);
 
 	debug_print("Getting messages from %s into %s...\n", mbox, dest->path);
 
@@ -322,9 +322,15 @@ gint lock_mbox(const gchar *base, LockType type)
 			return -1;
 		}
 
-		if (fprintf(lockfp, "%d\n", getpid()) < 0 ||
-		    fclose(lockfp) == EOF) {
-			FILE_OP_ERROR(lockfile, "fopen||fclose");
+		if (fprintf(lockfp, "%d\n", getpid()) < 0) {
+			FILE_OP_ERROR(lockfile, "fprintf");
+			g_free(lockfile);
+			fclose(lockfp);
+			return -1;
+		}
+
+		if (fclose(lockfp) == EOF) {
+			FILE_OP_ERROR(lockfile, "fclose");
 			g_free(lockfile);
 			return -1;
 		}
@@ -358,9 +364,9 @@ gint lock_mbox(const gchar *base, LockType type)
 #endif
 
 #if HAVE_FLOCK
-		if ((lockfd = open(base, O_RDWR)) < 0) {
+		if ((lockfd = g_open(base, O_RDWR, 0)) < 0) {
 #else
-		if ((lockfd = open(base, O_RDWR)) < 0) {
+		if ((lockfd = g_open(base, O_RDWR, 0)) < 0) {
 #endif
 			FILE_OP_ERROR(base, "open");
 			return -1;
@@ -675,9 +681,9 @@ gint export_to_mbox(FolderItem *src, const gchar *mbox)
 	GSList *mlist;
 	gint ret;
 	
-	g_return_val_if_fail(src != NULL, -1);
-	g_return_val_if_fail(src->folder != NULL, -1);
-	g_return_val_if_fail(mbox != NULL, -1);
+	cm_return_val_if_fail(src != NULL, -1);
+	cm_return_val_if_fail(src->folder != NULL, -1);
+	cm_return_val_if_fail(mbox != NULL, -1);
 
 	debug_print("Exporting messages from %s into %s...\n",
 		    src->path, mbox);
