@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2008 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -461,8 +461,8 @@ void mimeview_show_message(MimeView *mimeview, MimeInfo *mimeinfo,
 
 	mimeview_clear(mimeview);
 
-	g_return_if_fail(file != NULL);
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(file != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 
 	mimeview->mimeinfo = mimeinfo;
 
@@ -575,7 +575,7 @@ static void mimeview_set_multipart_tree(MimeView *mimeview,
 {
 	GtkCMCTreeNode *node;
 
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 
 	while (mimeinfo != NULL) {
 		node = mimeview_append_part(mimeview, mimeinfo, parent);
@@ -639,7 +639,7 @@ static GtkCMCTreeNode *mimeview_append_part(MimeView *mimeview,
 		str[COL_NAME] = (gchar *) get_part_name(partinfo);
 
 	node = gtk_sctree_insert_node(ctree, parent, NULL, str, 0,
-				     NULL, NULL, NULL, NULL,
+				     NULL, NULL,
 				     FALSE, TRUE);
 	gtk_cmctree_node_set_row_data(ctree, node, partinfo);
 
@@ -860,8 +860,8 @@ static void update_signature_noticeview(MimeView *mimeview, MimeInfo *mimeinfo,
 	StockPixmap icon = STOCK_PIXMAP_PRIVACY_SIGNED;
 	SignatureStatus mycode = SIGNATURE_UNCHECKED;
 	
-	g_return_if_fail(mimeview != NULL);
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(mimeview != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 	
 	if (special)
 		mycode = code;
@@ -1171,8 +1171,8 @@ static void update_signature_info(MimeView *mimeview, MimeInfo *selected)
 	MimeInfo *siginfo;
 	MimeInfo *first_text;
 	
-	g_return_if_fail(mimeview != NULL);
-	g_return_if_fail(selected != NULL);
+	cm_return_if_fail(mimeview != NULL);
+	cm_return_if_fail(selected != NULL);
 	
 	if (selected->type == MIMETYPE_MESSAGE 
 	&&  !g_ascii_strcasecmp(selected->subtype, "rfc822")) {
@@ -1251,7 +1251,7 @@ static void mimeview_start_drag(GtkWidget *widget, gint button,
 	GdkDragContext *context;
 	MimeInfo *partinfo;
 
-	g_return_if_fail(mimeview != NULL);
+	cm_return_if_fail(mimeview != NULL);
 
 	partinfo = mimeview_get_selected_part(mimeview);
 	if (partinfo->disposition == DISPOSITIONTYPE_INLINE) return;
@@ -1451,13 +1451,13 @@ static gint mimeview_key_pressed(GtkWidget *widget, GdkEventKey *event,
 		KEY_PRESS_EVENT_STOP();
 		mimeview_launch(mimeview, NULL);
 		return TRUE;
-#ifndef G_OS_WIN32
 	case GDK_o:
 		BREAK_ON_MODIFIER_KEY();
 		KEY_PRESS_EVENT_STOP();
+#ifndef G_OS_WIN32
 		mimeview_open_with(mimeview);
-		return TRUE;
 #endif
+		return TRUE;
 	case GDK_c:
 		BREAK_ON_MODIFIER_KEY();
 		KEY_PRESS_EVENT_STOP();
@@ -1769,7 +1769,7 @@ static void mimeview_save_as(MimeView *mimeview)
 
 	partinfo = mimeview_get_part_to_use(mimeview);
 
-	g_return_if_fail(partinfo != NULL);
+	cm_return_if_fail(partinfo != NULL);
 	
 	if (get_part_name(partinfo) == NULL) {
 		return;
@@ -1791,7 +1791,7 @@ static void mimeview_save_as(MimeView *mimeview)
 
 	subst_for_filename(partname);
 	
-	if (prefs_common.attach_save_dir)
+	if (prefs_common.attach_save_dir && *prefs_common.attach_save_dir)
 		filepath = g_strconcat(prefs_common.attach_save_dir,
 				       G_DIR_SEPARATOR_S, partname, NULL);
 	else
@@ -1825,7 +1825,7 @@ static void mimeview_display_as_text(MimeView *mimeview)
 
 	partinfo = mimeview_get_part_to_use(mimeview);
 	mimeview_select_mimepart_icon(mimeview, partinfo);
-	g_return_if_fail(partinfo != NULL);
+	cm_return_if_fail(partinfo != NULL);
 	mimeview_show_message_part(mimeview, partinfo);
 }
 
@@ -1840,7 +1840,7 @@ static void mimeview_launch(MimeView *mimeview, MimeInfo *partinfo)
 	if (!partinfo)
 		partinfo = mimeview_get_part_to_use(mimeview);
 
-	g_return_if_fail(partinfo != NULL);
+	cm_return_if_fail(partinfo != NULL);
 
 	filename = procmime_get_tmp_file_name(partinfo);
 
@@ -1883,7 +1883,7 @@ static void mimeview_open_part_with(MimeView *mimeview, MimeInfo *partinfo, gboo
 	gchar *uri;
 	int r = 0;
 #endif
-	g_return_if_fail(partinfo != NULL);
+	cm_return_if_fail(partinfo != NULL);
 
 	filename = procmime_get_tmp_file_name(partinfo);
 
@@ -2251,7 +2251,9 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 		stockp = STOCK_PIXMAP_MIME_MESSAGE;
 		break;
 	case MIMETYPE_APPLICATION:
-		if (mimeinfo->subtype && !g_ascii_strcasecmp(mimeinfo->subtype, "pgp-signature"))
+		if (mimeinfo->subtype && (!g_ascii_strcasecmp(mimeinfo->subtype, "pgp-signature")
+		    || !g_ascii_strcasecmp(mimeinfo->subtype, "x-pkcs7-signature")
+		    || !g_ascii_strcasecmp(mimeinfo->subtype, "pkcs7-signature")))
 			stockp = STOCK_PIXMAP_MIME_PGP_SIG;
 		else if (mimeinfo->subtype && !g_ascii_strcasecmp(mimeinfo->subtype, "pdf"))
 			stockp = STOCK_PIXMAP_MIME_PDF;
@@ -2421,7 +2423,7 @@ static void icon_list_create(MimeView *mimeview, MimeInfo *mimeinfo)
 {
 	GtkRequisition size;
 
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 
 	while (mimeinfo != NULL) {
 		if (mimeinfo->type != MIMETYPE_MULTIPART)
