@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -819,7 +819,7 @@ static PrefParam param[] = {
 #endif
 	{"ext_editor_command", DEFAULT_EDITOR_CMD,
 	 &SPECIFIC_PREFS.ext_editor_cmd, P_STRING, NULL, NULL, NULL},
-	{"cmds_use_system_default", "FALSE",
+	{"cmds_use_system_default", "TRUE",
 	 &prefs_common.cmds_use_system_default, P_BOOL, NULL, NULL, NULL},
 	{"add_address_by_click", "FALSE", &prefs_common.add_address_by_click,
 	 P_BOOL, NULL, NULL, NULL},
@@ -1021,6 +1021,11 @@ static PrefParam param[] = {
 	{"addressbook_folderselwin_height", "-1", &prefs_common.addressbook_folderselwin_height, P_INT,
 	 NULL, NULL, NULL},
 
+	{"aboutwin_width", "450", &prefs_common.aboutwin_width, P_INT,
+	 NULL, NULL, NULL},
+	{"aboutwin_height", "500", &prefs_common.aboutwin_height, P_INT,
+	 NULL, NULL, NULL},
+
 	/* Hidden */
 	{"warn_dnd", "1", &prefs_common.warn_dnd, P_INT,
 	 NULL, NULL, NULL},
@@ -1096,6 +1101,14 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"print_paper_orientation", "0", &prefs_common.print_paper_orientation, P_INT,
 	 NULL, NULL, NULL},
+	{"print_margin_top", "-1", &prefs_common.print_margin_top, P_INT,
+	 NULL, NULL, NULL},
+	{"print_margin_bottom", "-1", &prefs_common.print_margin_bottom, P_INT,
+	 NULL, NULL, NULL},
+	{"print_margin_left", "-1", &prefs_common.print_margin_left, P_INT,
+	 NULL, NULL, NULL},
+	{"print_margin_right", "-1", &prefs_common.print_margin_right, P_INT,
+	 NULL, NULL, NULL},
 	{"print_use_color", "0", &prefs_common.print_use_color, P_INT,
 	 NULL, NULL, NULL},
 	{"print_use_collate", "0", &prefs_common.print_use_collate, P_INT,
@@ -1121,6 +1134,9 @@ static PrefParam param[] = {
 	{"inherit_folder_properties", "FALSE", &prefs_common.inherit_folder_props, P_BOOL,
 	 NULL, NULL, NULL},
 
+	{"flush_metadata", "TRUE", &prefs_common.flush_metadata, P_BOOL,
+	 NULL, NULL, NULL},
+
 	{NULL, NULL, NULL, P_OTHER, NULL, NULL, NULL}
 };
 
@@ -1330,8 +1346,8 @@ void pref_get_unescaped_pref(gchar *out, const gchar *in)
 
 	*out = '\0';
 
-	g_return_if_fail( in != NULL );
-	g_return_if_fail( out != NULL );
+	cm_return_if_fail( in != NULL );
+	cm_return_if_fail( out != NULL );
 
 	i = in;
 	o = out;
@@ -1366,8 +1382,8 @@ void pref_get_escaped_pref(gchar *out, const gchar *in)
 
 	*out = '\0';
 
-	g_return_if_fail( in != NULL );
-	g_return_if_fail( out != NULL );
+	cm_return_if_fail( in != NULL );
+	cm_return_if_fail( out != NULL );
 
 	i = in;
 	o = out;
@@ -1396,7 +1412,7 @@ void pref_set_textview_from_pref(GtkTextView *textview, const gchar *txt)
 	GtkTextBuffer *buffer;
 	gchar *out = NULL;
 
-	g_return_if_fail( textview != NULL );
+	cm_return_if_fail( textview != NULL );
 
 	buffer = gtk_text_view_get_buffer(textview);
 
@@ -1418,7 +1434,7 @@ void pref_set_entry_from_pref(GtkEntry *entry, const gchar *txt)
 {
 	gchar *out = NULL;
 
-	g_return_if_fail( entry != NULL );
+	cm_return_if_fail( entry != NULL );
 	if (!txt) {
 		gtk_entry_set_text(entry, "");
 	} else {
@@ -1439,15 +1455,15 @@ gchar *pref_get_pref_from_textview(GtkTextView *textview)
 	GtkTextIter start, end;
 	gchar *out, *tmp;
 	
-	g_return_val_if_fail( textview != NULL, "" );
+	cm_return_val_if_fail( textview != NULL, "" );
 
 	buffer = gtk_text_view_get_buffer(textview);
 	gtk_text_buffer_get_start_iter(buffer, &start);
 	gtk_text_buffer_get_iter_at_offset(buffer, &end, -1);
 	tmp = gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
 	out = malloc(2*strlen(tmp)+1);
-	
-	pref_get_escaped_pref(out, tmp);
+	if (out)
+		pref_get_escaped_pref(out, tmp);
 	g_free(tmp);
 
 	return out?out:"";
@@ -1459,12 +1475,13 @@ gchar *pref_get_pref_from_entry(GtkEntry *entry)
 {
 	gchar *out, *tmp;
 
-	g_return_val_if_fail( entry != NULL, "" );
+	cm_return_val_if_fail( entry != NULL, "" );
 
 	tmp = gtk_editable_get_chars(GTK_EDITABLE(entry), 0, -1);
 	out = malloc(2*strlen(tmp)+1);
-
-	pref_get_escaped_pref(out, tmp);
+	
+	if (out)
+		pref_get_escaped_pref(out, tmp);
 	g_free(tmp);
 
 	return out?out:"";
@@ -1563,6 +1580,11 @@ gboolean prefs_common_get_use_shred(void)
 	return prefs_common.use_shred;
 }
 
+gboolean prefs_common_get_flush_metadata (void)
+{
+	return prefs_common.flush_metadata;
+}
+
 PrefsCommon *prefs_common_get_prefs(void)
 {
 	return &prefs_common;
