@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -139,6 +139,7 @@ struct _PrefsCommon
 	gint linewrap_len;
 	gboolean linewrap_quote;
 	gboolean linewrap_pastes;
+	gboolean primary_paste_unselects;
 	gboolean autowrap;
 	gboolean auto_indent;
 	gboolean auto_exteditor;
@@ -166,7 +167,6 @@ struct _PrefsCommon
 	gboolean block_cursor;
 	gchar *quote_chars;
 	
-#if USE_ENCHANT
 	gboolean enable_aspell;
 	gchar *dictionary;
 	gchar *alt_dictionary;
@@ -175,7 +175,6 @@ struct _PrefsCommon
 	gboolean recheck_when_changing_dict;
 	gboolean use_alternate;
 	gboolean use_both_dicts;
-#endif
         
 	/* Display */
 	/* obsolete fonts */
@@ -331,16 +330,6 @@ struct _PrefsCommon
 
 	GList *mime_open_cmd_history;
 
-#if USE_GPGME
-	/* Privacy */
-	gboolean auto_check_signatures;
-	gboolean gpg_signature_popup;
-	gboolean store_passphrase;
-	gint store_passphrase_timeout;
-	gboolean passphrase_grab;
-	gboolean gpg_warning;
-#endif /* USE_GPGME */
-
 	/* Addressbook */
 	gboolean addressbook_use_editaddress_dialog;
 	gint addressbook_hpaned_pos;
@@ -370,8 +359,10 @@ struct _PrefsCommon
 	gint apply_per_account_filtering_rules;
 
 	/* Other */
+#ifndef G_OS_WIN32
 	gchar *uri_cmd;
 	gchar *print_cmd;
+#endif
 	gchar *ext_editor_cmd;
 	gboolean cmds_use_system_default;
 
@@ -398,10 +389,10 @@ struct _PrefsCommon
 	gboolean enable_filtering_debug_folder_proc;
 	gboolean enable_filtering_debug_pre_proc;
 	gboolean enable_filtering_debug_post_proc;
-    gboolean filtering_debug_cliplog;
-    guint filtering_debug_loglength;
+	gboolean filtering_debug_cliplog;
+	guint filtering_debug_loglength;
 
-    gboolean confirm_on_exit;
+	gboolean confirm_on_exit;
 	gboolean session_passwords;
 	gboolean clean_on_exit;
 	gboolean ask_on_clean;
@@ -433,6 +424,7 @@ struct _PrefsCommon
 	GList *summary_search_body_history;
 	GList *summary_search_adv_condition_history;
 	GList *message_search_history;
+	GList *compose_save_to_history;
 
 	gint filteringwin_width;
 	gint filteringwin_height;
@@ -473,6 +465,8 @@ struct _PrefsCommon
 	gint addressaddwin_height;
 	gint addressbook_folderselwin_width;
 	gint addressbook_folderselwin_height;
+	gint aboutwin_width;
+	gint aboutwin_height;
 
 	gint warn_dnd;
 	gint broken_are_utf8;
@@ -486,6 +480,11 @@ struct _PrefsCommon
 	
 	gchar *print_paper_type;
 	gint print_paper_orientation;
+	gint print_margin_top;
+	gint print_margin_bottom;
+	gint print_margin_left;
+	gint print_margin_right;
+  
 	gint print_use_color;
 	gint print_use_collate;
 	gint print_use_reverse;
@@ -498,6 +497,7 @@ struct _PrefsCommon
 	gboolean use_shred;
 	gboolean two_line_vert;
 	gboolean inherit_folder_props;
+	gboolean flush_metadata;
 
 };
 
