@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -227,7 +227,7 @@ void prefs_filtering_open(GSList ** p_processing,
 static void prefs_filtering_size_allocate_cb(GtkWidget *widget,
 					 GtkAllocation *allocation)
 {
-	g_return_if_fail(allocation != NULL);
+	cm_return_if_fail(allocation != NULL);
 
 	prefs_common.filteringwin_width = allocation->width;
 	prefs_common.filteringwin_height = allocation->height;
@@ -254,7 +254,7 @@ static void prefs_filtering_account_option_menu_populate(void)
 
 	accounts = account_get_list();
 
-	g_return_if_fail(accounts != NULL);
+	cm_return_if_fail(accounts != NULL);
 
 	COMBOBOX_ADD(filtering.account_combobox_list, Q_("Filtering Account Menu|All"), 0);
 	for (; accounts != NULL; accounts = accounts->next) {
@@ -653,9 +653,13 @@ static void rename_path(GSList * filters,
 	gint oldpathlen;
         GSList * action_cur;
         GSList * cur;
-
+	const gchar *separator=G_DIR_SEPARATOR_S;
+	gboolean matched = FALSE;
+#ifdef G_OS_WIN32
+again:
+#endif
 	oldpathlen = strlen(old_path);
-	old_path_with_sep = g_strconcat(old_path,G_DIR_SEPARATOR_S,NULL);
+	old_path_with_sep = g_strconcat(old_path,separator,NULL);
 
 	for (cur = filters; cur != NULL; cur = cur->next) {
 		FilteringProp   *filtering = (FilteringProp *)cur->data;
@@ -685,28 +689,30 @@ static void rename_path(GSList * filters,
                                         while (*base == G_DIR_SEPARATOR) base++;
                                         if (*base == '\0')
                                                 dest_path = g_strconcat(prefix,
-                                                    G_DIR_SEPARATOR_S,
+                                                    separator,
                                                     new_path, NULL);
                                         else
                                                 dest_path = g_strconcat(prefix,
-                                                    G_DIR_SEPARATOR_S,
+                                                    separator,
                                                     new_path,
-                                                    G_DIR_SEPARATOR_S,
+                                                    separator,
                                                     base, NULL);
                                         
                                         g_free(prefix);
                                         g_free(action->destination);
                                         action->destination = dest_path;
+					matched = TRUE;
                                 } else { /* for non-leaf folders */
                                         /* compare with trailing slash */
                                         if (!strncmp(old_path_with_sep, action->destination, oldpathlen+1)) {
                                                 
                                                 suffix = action->destination + oldpathlen + 1;
                                                 dest_path = g_strconcat(new_path,
-                                                    G_DIR_SEPARATOR_S,
+                                                    separator,
                                                     suffix, NULL);
                                                 g_free(action->destination);
                                                 action->destination = dest_path;
+						matched = TRUE;
                                         }
                                 }
                         } else {
@@ -715,10 +721,19 @@ static void rename_path(GSList * filters,
                                         dest_path = g_strdup(new_path);
                                         g_free(action->destination);
                                         action->destination = dest_path;
+					matched = TRUE;
                                 }
                         }
                 }
         }
+	
+	g_free(old_path_with_sep);
+#ifdef G_OS_WIN32
+	if (!strcmp(separator, G_DIR_SEPARATOR_S) && !matched) {
+		separator = "/";
+		goto again;
+	}
+#endif
 }
 
 static gboolean prefs_filtering_rename_path_func(GNode *node, gpointer data)
@@ -733,9 +748,9 @@ static gboolean prefs_filtering_rename_path_func(GNode *node, gpointer data)
 	old_path = paths[0];
 	new_path = paths[1];
 
-	g_return_val_if_fail(old_path != NULL, FALSE);
-	g_return_val_if_fail(new_path != NULL, FALSE);
-	g_return_val_if_fail(node != NULL, FALSE);
+	cm_return_val_if_fail(old_path != NULL, FALSE);
+	cm_return_val_if_fail(new_path != NULL, FALSE);
+	cm_return_val_if_fail(node != NULL, FALSE);
 
         item = node->data;
         if (!item || !item->prefs)
@@ -786,9 +801,9 @@ static gboolean prefs_filtering_rename_tag_func(GNode *node, gpointer data)
 	old_tag = tags[0];
 	new_tag = tags[1];
 
-	g_return_val_if_fail(old_tag != NULL, FALSE);
-	g_return_val_if_fail(new_tag != NULL, FALSE);
-	g_return_val_if_fail(node != NULL, FALSE);
+	cm_return_val_if_fail(old_tag != NULL, FALSE);
+	cm_return_val_if_fail(new_tag != NULL, FALSE);
+	cm_return_val_if_fail(node != NULL, FALSE);
 
         item = node->data;
         if (!item || !item->prefs)
@@ -873,8 +888,8 @@ static gboolean prefs_filtering_delete_path_func(GNode *node, gpointer data)
 	FolderItem *item;
         GSList ** p_filters;
 	
-	g_return_val_if_fail(path != NULL, FALSE);
-	g_return_val_if_fail(node != NULL, FALSE);
+	cm_return_val_if_fail(path != NULL, FALSE);
+	cm_return_val_if_fail(node != NULL, FALSE);
 
         item = node->data;
         if (!item || !item->prefs)
@@ -1034,14 +1049,15 @@ static void prefs_filtering_set_list(void)
 static gint prefs_filtering_list_view_set_row(gint row, FilteringProp * prop)
 {
 	GtkTreeView *list_view = GTK_TREE_VIEW(filtering.cond_list_view);
-	gchar *str;
+	gchar *str = NULL;
 	GtkListStore *list_store;
 	gchar *name = NULL;
 	gint account_id = 0;
 	gchar *account_name = (gchar *)Q_("Filtering Account Menu|All");
 	gboolean enabled = TRUE;
 
-	str = filteringprop_to_string(prop);
+	if (prop)
+		str = filteringprop_to_string(prop);
 	if (str == NULL)
 		return -1;
 
