@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto & the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto & the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -442,7 +442,7 @@ static void prefs_folder_column_set_view(void)
 		(gtk_tree_view_get_model(GTK_TREE_VIEW
 			(folder_col.shown_list_view)), NULL);
 
-	g_return_if_fail
+	cm_return_if_fail
 		(stock_n_rows + shown_n_rows == N_FOLDER_COLS);
 
 	for (row = 0; row < stock_n_rows; row++) {
