@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -576,8 +576,8 @@ void textview_reflect_prefs(TextView *textview)
 void textview_show_part(TextView *textview, MimeInfo *mimeinfo, FILE *fp)
 {
 	START_TIMING("");
-	g_return_if_fail(mimeinfo != NULL);
-	g_return_if_fail(fp != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(fp != NULL);
 
 	if ((mimeinfo->type == MIMETYPE_MULTIPART) ||
 	    ((mimeinfo->type == MIMETYPE_MESSAGE) && !g_ascii_strcasecmp(mimeinfo->subtype, "rfc822"))) {
@@ -622,7 +622,7 @@ static void textview_add_part(TextView *textview, MimeInfo *mimeinfo)
 	gint charcount;
 	START_TIMING("");
 
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
 	text = GTK_TEXT_VIEW(textview->text);
 	buffer = gtk_text_view_get_buffer(text);
 	charcount = gtk_text_buffer_get_char_count(buffer);
@@ -832,7 +832,7 @@ static void recursive_add_parts(TextView *textview, GNode *node)
 
 static void textview_add_parts(TextView *textview, MimeInfo *mimeinfo)
 {
-	g_return_if_fail(mimeinfo != NULL);
+	cm_return_if_fail(mimeinfo != NULL);
         
         recursive_add_parts(textview, mimeinfo->node);
 }
@@ -1111,7 +1111,7 @@ static void textview_show_html(TextView *textview, FILE *fp,
 	gint lines = 0;
 
 	parser = sc_html_parser_new(fp, conv);
-	g_return_if_fail(parser != NULL);
+	cm_return_if_fail(parser != NULL);
 
 	while ((str = sc_html_parse(parser)) != NULL) {
 	        if (parser->state == SC_HTML_HREF) {
@@ -1152,7 +1152,7 @@ static void textview_show_ertf(TextView *textview, FILE *fp,
 	gint lines = 0;
 
 	parser = ertf_parser_new(fp, conv);
-	g_return_if_fail(parser != NULL);
+	cm_return_if_fail(parser != NULL);
 
 	while ((str = ertf_parse(parser)) != NULL) {
 		textview_write_line(textview, str, NULL, FALSE);
@@ -1224,6 +1224,7 @@ static void textview_make_clickable_parts(TextView *textview,
 		{"https://", strcasestr, get_uri_part,   make_uri_string},
 		{"ftp://",   strcasestr, get_uri_part,   make_uri_string},
 		{"sftp://",  strcasestr, get_uri_part,   make_uri_string},
+		{"gopher://",strcasestr, get_uri_part,   make_uri_string},
 		{"www.",     strcasestr, get_uri_part,   make_http_string},
 		{"mailto:",  strcasestr, get_uri_part,   make_uri_string},
 		{"@",        strcasestr, get_email_part, make_email_string}
@@ -1535,16 +1536,18 @@ do_quote:
 			} else {
 				g_print("oops (%d %d)\n",
 					real_quotelevel, textview->prev_quote_level);
-			}		
-			if (lasturi->is_quote == FALSE) {
-				textview->prev_quote_level = -1;
-				goto do_quote;
+			}	
+			if (lasturi) {	
+				if (lasturi->is_quote == FALSE) {
+					textview->prev_quote_level = -1;
+					goto do_quote;
+				}
+				e_len = lasturi->data ? strlen(lasturi->data):0;
+				n_len = strlen(buf);
+				lasturi->data = g_realloc((gchar *)lasturi->data, e_len + n_len + 1);
+				strcpy((gchar *)lasturi->data + e_len, buf);
+				*((gchar *)lasturi->data + e_len + n_len) = '\0';
 			}
-			e_len = lasturi->data ? strlen(lasturi->data):0;
-			n_len = strlen(buf);
-			lasturi->data = g_realloc((gchar *)lasturi->data, e_len + n_len + 1);
-			strcpy((gchar *)lasturi->data + e_len, buf);
-			*((gchar *)lasturi->data + e_len + n_len) = '\0';
 		}
 	} else {
 		textview_make_clickable_parts(textview, fg_color, "link", buf, FALSE);
@@ -1720,8 +1723,8 @@ void textview_set_text(TextView *textview, const gchar *text)
 	GtkTextView *view;
 	GtkTextBuffer *buffer;
 
-	g_return_if_fail(textview != NULL);
-	g_return_if_fail(text != NULL);
+	cm_return_if_fail(textview != NULL);
+	cm_return_if_fail(text != NULL);
 
 	textview_clear(textview);
 
@@ -1762,6 +1765,7 @@ static gboolean header_is_internal(Header *header)
 		 "X-Claws-Account-Id:", "X-Claws-Sign:", "X-Claws-Encrypt:", 
 		 "X-Claws-Privacy-System:", "X-Claws-End-Special-Headers:",
 		 "X-Sylpheed-Account-Id:", "X-Sylpheed-Sign:", "X-Sylpheed-Encrypt:", 
+		 "X-Claws-Auto-Wrapping:", "X-Claws-Auto-Indent:",
 		 "X-Sylpheed-Privacy-System:", "X-Sylpheed-End-Special-Headers:",
 		 NULL};
 	int i;
@@ -1781,7 +1785,7 @@ static GPtrArray *textview_scan_header(TextView *textview, FILE *fp)
 	Header *header;
 	gint i;
 
-	g_return_val_if_fail(fp != NULL, NULL);
+	cm_return_val_if_fail(fp != NULL, NULL);
 
 	if (textview->show_all_headers) {
 		headers = procheader_get_header_array_asis(fp);
@@ -1863,7 +1867,7 @@ static void textview_show_face(TextView *textview)
 		gtk_widget_destroy(textview->image);
 	
 	textview->image = face_get_from_header(msginfo->extradata->face);
-	g_return_if_fail(textview->image != NULL);
+	cm_return_if_fail(textview->image != NULL);
 
 	gtk_widget_show(textview->image);
 	
@@ -1891,7 +1895,7 @@ void textview_show_icon(TextView *textview, const gchar *stock_id)
 		gtk_widget_destroy(textview->image);
 	
 	textview->image = gtk_image_new_from_stock(stock_id, GTK_ICON_SIZE_DIALOG);
-	g_return_if_fail(textview->image != NULL);
+	cm_return_if_fail(textview->image != NULL);
 
 	gtk_widget_show(textview->image);
 	
@@ -1937,7 +1941,7 @@ static void textview_show_xface(TextView *textview)
 	textview->image = xface_get_from_header(msginfo->extradata->xface,
 				&textview->text->style->white,
 				window);
-	g_return_if_fail(textview->image != NULL);
+	cm_return_if_fail(textview->image != NULL);
 
 	gtk_widget_show(textview->image);
 	
@@ -2033,7 +2037,7 @@ static void textview_show_contact_pic(TextView *textview)
 		textview->image = gtk_image_new_from_pixbuf(picture);
 		g_object_unref(picture);
 	}
-	g_return_if_fail(textview->image != NULL);
+	cm_return_if_fail(textview->image != NULL);
 
 	gtk_widget_show(textview->image);
 	
@@ -2136,11 +2140,11 @@ static void textview_show_header(TextView *textview, GPtrArray *headers)
 	Header *header;
 	gint i;
 
-	g_return_if_fail(headers != NULL);
+	cm_return_if_fail(headers != NULL);
 
 	for (i = 0; i < headers->len; i++) {
 		header = g_ptr_array_index(headers, i);
-		g_return_if_fail(header->name != NULL);
+		cm_return_if_fail(header->name != NULL);
 
 		gtk_text_buffer_get_end_iter (buffer, &iter);
 		if(prefs_common.trans_hdr == TRUE) {
@@ -2443,17 +2447,12 @@ static void textview_uri_update(TextView *textview, gint x, gint y)
 		TEXTVIEW_STATUSBAR_POP(textview);
 
 		if (uri) {
-			char *trimmed_uri;
-
 			if (!uri->is_quote)
 				gtk_text_buffer_apply_tag_by_name(buffer,
 							  "link-hover",
 							  &start_iter,
 							  &end_iter);
-
-			trimmed_uri = trim_string(uri->uri, 60);
-			TEXTVIEW_STATUSBAR_PUSH(textview, trimmed_uri);
-			g_free(trimmed_uri);
+			TEXTVIEW_STATUSBAR_PUSH(textview, uri->uri);
 		}
 	}
 }
@@ -2932,7 +2931,7 @@ static void save_file_cb (GtkAction *action, TextView *textview)
 
 	subst_for_filename(filename);
 	
-	if (prefs_common.attach_save_dir)
+	if (prefs_common.attach_save_dir && *prefs_common.attach_save_dir)
 		filepath = g_strconcat(prefs_common.attach_save_dir,
 				       G_DIR_SEPARATOR_S, filename, NULL);
 	else
